--[[

Zotwee price source for TradeSkillMaster addon, v0.9.2
http://zotwee.info/

** This is NOT an official TradeSkillMaster addon **

]]

local ZWM = select(2, ...)
ZWM = LibStub("AceAddon-3.0"):NewAddon(ZWM, "TSM_Zotwee", "AceConsole-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("TradeSkillMaster_Zotwee") -- loads the localization table
ZWM.version = "0.9.2"
ZWM.moduleName = "TradeSkillMaster Zotwee"

local savedDBDefaults = {
  factionrealm = {},
  profile = {
    tooltip = true,
    marketValue = true,
    last24Price = true,
    last30Price = true,
    lastSeen = true,
    minBuyout = true
  }
}

-- Called once the player has loaded WOW.
function ZWM:OnInitialize()
  ZWM.db = LibStub:GetLibrary("AceDB-3.0"):New("TradeSkillMaster_ZotweeDB", savedDBDefaults, true)

  Zotwee:AddModule(ZWM)
  -- register this module with TSM
  ZWM:RegisterModule()
end

-- registers this module with TSM by first setting all fields and then calling TSMAPI:NewModule().
function ZWM:RegisterModule()
  ZWM.priceSources = {
    { key = "zotweeMarket", label = L["Zotwee Realm Market Value"], callback = "GetMarketData", arg = "market" },
    { key = "zotwee24h", label = L["Zotwee Last 24 hours Price"], callback = "GetMarketData", arg = "market24h" },
    { key = "zotwee30d", label = L["Zotwee Last 30 days Price"], callback = "GetMarketData", arg = "market30d" }
  }
  ZWM.tooltipOptions = { callback = "LoadTooltipOptions" }

  TSMAPI:NewModule(ZWM)
end

function ZWM:GetMarketData(itemID, key)
  if type(itemID) ~= "number" then itemID = TSMAPI:GetItemID(itemID) end

  local data = ZotweeMarketItem(itemID)

  if not data then return end

  if key and data[key] > 0 then
    return data[key]
  else
    return data
  end
end

function ZWM:GetTooltip(itemString, quantity)
  if not ZWM.db.profile.tooltip then return end
  if not strfind(itemString, "item:") then return end
  local itemID = TSMAPI:GetItemID(itemString)
  if not itemID then return end
  local data = ZWM:GetMarketData(itemString)
  local moneyCoinsTooltip = TSMAPI:GetMoneyCoinsTooltip()

  if not data then return end
  local text = {}

  if ZWM.db.profile.marketValue then
    if data.market and data.market > 0 then
      if moneyCoinsTooltip then
        if IsShiftKeyDown() then
          tinsert(text, { left = "  " .. format(L["Realm Market x%s:"], quantity), right = TSMAPI:FormatTextMoneyIcon(data.market * quantity, "|cffffffff", true) })
        else
          tinsert(text, { left = "  " .. L["Realm Market:"], right = TSMAPI:FormatTextMoneyIcon(data.market, "|cffffffff", true) })
        end
      else
        if IsShiftKeyDown() then
          tinsert(text, { left = "  " .. format(L["Realm Market x%s:"], quantity), right = TSMAPI:FormatTextMoney(data.market * quantity, "|cffffffff", true) })
        else
          tinsert(text, { left = "  " .. L["Realm Market:"], right = TSMAPI:FormatTextMoney(data.market, "|cffffffff", true) })
        end
      end
    end
  end
  if ZWM.db.profile.last24Price then
    if data.market24h and data.market24h > 0 then
      if moneyCoinsTooltip then
        if IsShiftKeyDown() then
          tinsert(text, { left = "  " .. format(L["Realm 24hrs Market x%s:"], quantity), right = TSMAPI:FormatTextMoneyIcon(data.market24h * quantity, "|cffffffff", true) })
        else
          tinsert(text, { left = "  " .. L["Realm 24hrs Market:"], right = TSMAPI:FormatTextMoneyIcon(data.market24h, "|cffffffff", true) })
        end
      else
        if IsShiftKeyDown() then
          tinsert(text, { left = "  " .. format(L["Realm 24hrs Market x%s:"], quantity), right = TSMAPI:FormatTextMoney(data.market24h * quantity, "|cffffffff", true) })
        else
          tinsert(text, { left = "  " .. L["Realm 24hrs Market:"], right = TSMAPI:FormatTextMoney(data.market24h, "|cffffffff", true) })
        end
      end
    end
  end
  if ZWM.db.profile.last30Price then
    if data.market30d and data.market30d > 0 then
      if moneyCoinsTooltip then
        if IsShiftKeyDown() then
          tinsert(text, { left = "  " .. format(L["Realm 30days Market x%s:"], quantity), right = TSMAPI:FormatTextMoneyIcon(data.market30d * quantity, "|cffffffff", true) })
        else
          tinsert(text, { left = "  " .. L["Realm 30days Market:"], right = TSMAPI:FormatTextMoneyIcon(data.market30d, "|cffffffff", true) })
        end
      else
        if IsShiftKeyDown() then
          tinsert(text, { left = "  " .. format(L["Realm 30days Market x%s:"], quantity), right = TSMAPI:FormatTextMoney(data.market30d * quantity, "|cffffffff", true) })
        else
          tinsert(text, { left = "  " .. L["Realm 30days Market:"], right = TSMAPI:FormatTextMoney(data.market30d, "|cffffffff", true) })
        end
      end
    end
  end
  if ZWM.db.profile.minBuyout then
    if data.minbuyout and data.minbuyout > 0 then
      if moneyCoinsTooltip then
        tinsert(text, { left = "  " .. L["Realm Min Buyout:"], right = TSMAPI:FormatTextMoneyIcon(data.minbuyout, "|cffffffff", true) })
      else
        tinsert(text, { left = "  " .. L["Realm Min Buyout:"], right = TSMAPI:FormatTextMoney(data.minbuyout, "|cffffffff", true) })
      end
    end
  end

  if ZWM.db.profile.lastSeen then
      if data.age then
        tinsert(text, { left = "  " .. L["Last Seen:"], right = "|cffffffff" .. format(L["%s ago"], SecondsToTime(data.age)) })
      end
  end
  
  if #text > 0 then
    local lastScan = Zotwee:GetLastUpdateTime()
    if lastScan then
      local diff = SecondsToTime(time() - lastScan)
      tinsert(text, 1, { left = "|cffffff00" .. "TSM Zotwee:", right = "|cffffffff" .. format(L["%s ago"], diff) })
    else
      tinsert(text, 1, { left = "|cffffff00" .. "TSM Zotwee:", right = "|cffffffff" .. L["No data yet"] })
    end
    return text
  end
end


function ZWM:LoadTooltipOptions(container)
  local page = {
    {
      type = "SimpleGroup",
      layout = "Flow",
      fullHeight = true,
      children = {
        {
          type = "CheckBox",
          label = L["Enable display of Zotwee data in tooltip."],
          relativeWidth = 1,
          settingInfo = { ZWM.db.profile, "tooltip" },
          callback = function(_, _, value)
            container:ReloadTab()
          end,
        },
        {
          type = "CheckBox",
          label = L["Display realm market price in tooltip."],
          disabled = not ZWM.db.profile.tooltip,
          relativeWidth = 0.49,
          settingInfo = { ZWM.db.profile, "marketValue" },
          tooltip = L["If checked, the market value of the item will be shown"],
        },
        {
          type = "CheckBox",
          label = L["Display last 24 hours realm price in tooltip."],
          disabled = not ZWM.db.profile.tooltip,
          settingInfo = { ZWM.db.profile, "last24Price" },
          tooltip = L["If checked, the last 24 hours price of the item will be shown."],
        },
        {
          type = "CheckBox",
          label = L["Display last 30 days realm price in tooltip."],
          disabled = not ZWM.db.profile.tooltip,
          settingInfo = { ZWM.db.profile, "last30Price" },
          tooltip = L["If checked, the last 30 days price of the item will be shown."],
        },
        {
          type = "CheckBox",
          label = L["Display minimum buyout realm price in tooltip."],
          disabled = not ZWM.db.profile.tooltip,
          settingInfo = { ZWM.db.profile, "minbuyout" },
          tooltip = L["If checked, the minimum buyout price of the item will be shown."],
        },
        {
          type = "CheckBox",
          label = L["Display the lastseen time for the item in tooltip."],
          disabled = not ZWM.db.profile.tooltip,
          settingInfo = { ZWM.db.profile, "lastSeen" },
          tooltip = L["If checked, the lastseen time for the item will be shown."],
        },
      },
    },
  }

  TSMAPI:BuildPage(container, page)
end